package main

import (
	"fmt"
	client "github.com/influxdata/influxdb1-client/v2"
	"math/rand"
	"time"
)

const (
	MyDB          = "LXF"
	username      = "root"
	password      = "root"
	MyMeasurement = "lxf_table"
	Displayed     = 5
)

func random(min, max int) int {
	return rand.Intn(max-min) + min
}

func queryDB(clnt client.Client, cmd string) (res []client.Result, err error) {
	q := client.Query{
		Command:  cmd,
		Database: MyDB,
	}

	answer, err := clnt.Query(q)
	if err == nil {
		if answer.Error() != nil {
			return res, answer.Error()
		}
		res = answer.Results
	} else {
		return res, err
	}

	return res, nil
}

func writePoints(clnt client.Client) {
	size := 15
	rand.Seed(time.Now().Unix())

	bp, _ := client.NewBatchPoints(client.BatchPointsConfig{
		Database:  MyDB,
		Precision: "s",
	})

	for i := 0; i < size; i++ {
		time.Sleep(time.Second)
		regions := []string{"europe", "usa", "asia", "africa"}
		tags := map[string]string{
			"cpu":      "cpu-total",
			"hostname": fmt.Sprintf("h_%d", random(0, 1000)),
			"region":   regions[i%len(regions)],
		}

		idle := rand.Float64() * 100.0
		fields := map[string]interface{}{
			"idle": idle,
			"busy": 100.0 - idle,
		}

		pt, err := client.NewPoint(MyMeasurement, tags, fields, time.Now())
		if err != nil {
			fmt.Println("Error: ", err)
		}
		bp.AddPoint(pt)
	}

	fmt.Printf("Writing points:% v \n", pt)

	err := clnt.Write(bp)
	if err != nil {
		fmt.Println(err)
	}
}

func main() {
	clnt, err := client.NewHTTPClient(client.HTTPConfig{
		Addr:     "http://localhost:8086",
		Username: username,
		Password: password,
	})

	if err != nil {
		fmt.Println("Error:", err)
		return
	}

	_, err = queryDB(clnt, fmt.Sprintf("DROP DATABASE %s", MyDB))
	if err != nil {
		fmt.Println("Error:", err)
		return
	}

	_, err = queryDB(clnt, fmt.Sprintf("CREATE DATABASE %s", MyDB))
	if err != nil {
		fmt.Println("Error:", err)
		return
	}

	writePoints(clnt)

	q := fmt.Sprintf("SELECT * FROM %s LIMIT %d", MyMeasurement, Displayed)
	res, err := queryDB(clnt, q)
	if err != nil {
		fmt.Println("Error:", err)
		return
	}

	fmt.Printf("result:% v \n", res)

	for i, row := range res[0].Series[0].Values {
		t, err := time.Parse(time.RFC3339, row[0].(string))
		if err != nil {
			fmt.Println("Error:", err)
			return
		}
		val := row[1]
		fmt.Printf("[%2d] %s: %s\n", i, t.Format(time.Stamp), val)
	}
}
